/*
Continuous Testing Toolkit
Copyright (C) 2009 Paul R. Holser, Jr.

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

package org.infinitest.toolkit;

import java.util.ArrayList;
import java.util.Collection;

import org.hamcrest.BaseMatcher;
import org.hamcrest.Description;

class SameContentsMatcher extends BaseMatcher<Collection<?>> {
    private final Collection<?> comparand;

    SameContentsMatcher(Collection<?> comparand) {
        this.comparand = comparand;
    }

    public boolean matches(Object target) {
        if (target == null)
            return comparand == null;

        return target instanceof Collection<?> && haveSameContents((Collection<?>) target, comparand);
    }

    public void describeTo(Description description) {
        description.appendText("a collection that has the same contents as ").appendValue(comparand);
    }

    private static boolean haveSameContents(Collection<?> first, Collection<?> second) {
        if (second == null)
            return false;

        if (first.size() != second.size())
            return false;

        Collection<?> copyOfFirst = new ArrayList<Object>(first);
        for (Object each : second)
            copyOfFirst.remove(each);

        return copyOfFirst.isEmpty();
    }
}
